@@ -256,6 +256,9 @@ void parse_bitrate(struct nlattr *bitrate_attr, char *buf, int buflen)
 	if (rinfo[NL80211_RATE_INFO_HE_DCM])
 		pos += snprintf(pos, buflen - (pos - buf),
 				" HE-DCM %d", nla_get_u8(rinfo[NL80211_RATE_INFO_HE_DCM]));
+	if (rinfo[NL80211_RATE_INFO_HE_RU_ALLOC])
+		pos += snprintf(pos, buflen - (pos - buf),
+				" HE-RU-ALLOC %d", nla_get_u8(rinfo[NL80211_RATE_INFO_HE_RU_ALLOC]));
 }
 
 static char *get_chain_signal(struct nlattr *attr_list)
@@ -325,6 +328,9 @@ static int print_sta_handler(struct nl_msg *msg, void *arg)
 		[NL80211_STA_INFO_TX_DURATION] = { .type = NLA_U64 },
 		[NL80211_STA_INFO_ACK_SIGNAL] = {.type = NLA_U8 },
 		[NL80211_STA_INFO_ACK_SIGNAL_AVG] = { .type = NLA_U8 },
+		[NL80211_STA_INFO_AIRTIME_LINK_METRIC] = { .type = NLA_U32 },
+		[NL80211_STA_INFO_CONNECTED_TO_AS] = { .type = NLA_FLAG },
+		[NL80211_STA_INFO_CONNECTED_TO_GATE] = { .type = NLA_FLAG },
 	};
 	char *chain;
 	struct timeval now;
@@ -494,6 +500,18 @@ static int print_sta_handler(struct nl_msg *msg, void *arg)
 		}
 		printf("\n\tmesh plink:\t%s", state_name);
 	}
+	if (sinfo[NL80211_STA_INFO_AIRTIME_LINK_METRIC])
+		printf("\n\tmesh airtime link metric: %d",
+			nla_get_u32(sinfo[NL80211_STA_INFO_AIRTIME_LINK_METRIC]));
+	if (sinfo[NL80211_STA_INFO_CONNECTED_TO_GATE])
+		printf("\n\tmesh connected to gate:\t%s",
+			nla_get_u8(sinfo[NL80211_STA_INFO_CONNECTED_TO_GATE]) ?
+			"yes" : "no");
+	if (sinfo[NL80211_STA_INFO_CONNECTED_TO_AS])
+		printf("\n\tmesh connected to auth server:\t%s",
+			nla_get_u8(sinfo[NL80211_STA_INFO_CONNECTED_TO_AS]) ?
+			"yes" : "no");
+
 	if (sinfo[NL80211_STA_INFO_LOCAL_PM]) {
 		printf("\n\tmesh local PS mode:\t");
 		print_power_mode(sinfo[NL80211_STA_INFO_LOCAL_PM]);
